# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/planning/proto/planning_semantic_map_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/planning/proto/planning_semantic_map_config.proto',
  package='apollo.planning',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n9modules/planning/proto/planning_semantic_map_config.proto\x12\x0f\x61pollo.planning\"\xc8\x02\n\x19PlanningSemanticMapConfig\x12\x12\n\nresolution\x18\x01 \x01(\x01\x12\x0e\n\x06height\x18\x64 \x01(\x05\x12\r\n\x05width\x18\x65 \x01(\x05\x12\x11\n\tego_idx_x\x18\x66 \x01(\x05\x12\x11\n\tego_idx_y\x18g \x01(\x05\x12\x1a\n\x12max_rand_delta_phi\x18h \x01(\x01\x12\x1e\n\x16max_ego_future_horizon\x18i \x01(\x01\x12\x1c\n\x14max_ego_past_horizon\x18j \x01(\x01\x12\x1e\n\x16max_obs_future_horizon\x18k \x01(\x01\x12\x1c\n\x14max_obs_past_horizon\x18l \x01(\x01\x12\x19\n\x10\x62\x61se_map_padding\x18\xc8\x01 \x01(\x05\x12\x1f\n\x16\x63ity_driving_max_speed\x18\xc9\x01 \x01(\x01'
)




_PLANNINGSEMANTICMAPCONFIG = _descriptor.Descriptor(
  name='PlanningSemanticMapConfig',
  full_name='apollo.planning.PlanningSemanticMapConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='resolution', full_name='apollo.planning.PlanningSemanticMapConfig.resolution', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='height', full_name='apollo.planning.PlanningSemanticMapConfig.height', index=1,
      number=100, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='width', full_name='apollo.planning.PlanningSemanticMapConfig.width', index=2,
      number=101, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ego_idx_x', full_name='apollo.planning.PlanningSemanticMapConfig.ego_idx_x', index=3,
      number=102, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ego_idx_y', full_name='apollo.planning.PlanningSemanticMapConfig.ego_idx_y', index=4,
      number=103, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_rand_delta_phi', full_name='apollo.planning.PlanningSemanticMapConfig.max_rand_delta_phi', index=5,
      number=104, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_ego_future_horizon', full_name='apollo.planning.PlanningSemanticMapConfig.max_ego_future_horizon', index=6,
      number=105, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_ego_past_horizon', full_name='apollo.planning.PlanningSemanticMapConfig.max_ego_past_horizon', index=7,
      number=106, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_obs_future_horizon', full_name='apollo.planning.PlanningSemanticMapConfig.max_obs_future_horizon', index=8,
      number=107, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_obs_past_horizon', full_name='apollo.planning.PlanningSemanticMapConfig.max_obs_past_horizon', index=9,
      number=108, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='base_map_padding', full_name='apollo.planning.PlanningSemanticMapConfig.base_map_padding', index=10,
      number=200, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='city_driving_max_speed', full_name='apollo.planning.PlanningSemanticMapConfig.city_driving_max_speed', index=11,
      number=201, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=79,
  serialized_end=407,
)

DESCRIPTOR.message_types_by_name['PlanningSemanticMapConfig'] = _PLANNINGSEMANTICMAPCONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PlanningSemanticMapConfig = _reflection.GeneratedProtocolMessageType('PlanningSemanticMapConfig', (_message.Message,), {
  'DESCRIPTOR' : _PLANNINGSEMANTICMAPCONFIG,
  '__module__' : 'modules.planning.proto.planning_semantic_map_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.PlanningSemanticMapConfig)
  })
_sym_db.RegisterMessage(PlanningSemanticMapConfig)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/planning/proto/math/cos_theta_smoother_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/planning/proto/math/cos_theta_smoother_config.proto',
  package='apollo.planning',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n;modules/planning/proto/math/cos_theta_smoother_config.proto\x12\x0f\x61pollo.planning\"\xc8\x02\n\x16\x43osThetaSmootherConfig\x12(\n\x19weight_cos_included_angle\x18\x01 \x01(\x01:\x05\x31\x30\x30\x30\x30\x12\x1f\n\x14weight_anchor_points\x18\x02 \x01(\x01:\x01\x31\x12\x18\n\rweight_length\x18\x03 \x01(\x01:\x01\x31\x12\x16\n\x0bprint_level\x18\x04 \x01(\x05:\x01\x30\x12\"\n\x15max_num_of_iterations\x18\x05 \x01(\x05:\x03\x35\x30\x30\x12(\n\x1c\x61\x63\x63\x65ptable_num_of_iterations\x18\x06 \x01(\x05:\x02\x31\x35\x12\x12\n\x03tol\x18\x07 \x01(\x01:\x05\x31\x65-08\x12\x1b\n\x0e\x61\x63\x63\x65ptable_tol\x18\x08 \x01(\x01:\x03\x30.1\x12\x32\n#ipopt_use_automatic_differentiation\x18\t \x01(\x08:\x05\x66\x61lse'
)




_COSTHETASMOOTHERCONFIG = _descriptor.Descriptor(
  name='CosThetaSmootherConfig',
  full_name='apollo.planning.CosThetaSmootherConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='weight_cos_included_angle', full_name='apollo.planning.CosThetaSmootherConfig.weight_cos_included_angle', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(10000),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weight_anchor_points', full_name='apollo.planning.CosThetaSmootherConfig.weight_anchor_points', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weight_length', full_name='apollo.planning.CosThetaSmootherConfig.weight_length', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='print_level', full_name='apollo.planning.CosThetaSmootherConfig.print_level', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_num_of_iterations', full_name='apollo.planning.CosThetaSmootherConfig.max_num_of_iterations', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=500,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acceptable_num_of_iterations', full_name='apollo.planning.CosThetaSmootherConfig.acceptable_num_of_iterations', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=15,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tol', full_name='apollo.planning.CosThetaSmootherConfig.tol', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1e-08),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acceptable_tol', full_name='apollo.planning.CosThetaSmootherConfig.acceptable_tol', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipopt_use_automatic_differentiation', full_name='apollo.planning.CosThetaSmootherConfig.ipopt_use_automatic_differentiation', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=81,
  serialized_end=409,
)

DESCRIPTOR.message_types_by_name['CosThetaSmootherConfig'] = _COSTHETASMOOTHERCONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CosThetaSmootherConfig = _reflection.GeneratedProtocolMessageType('CosThetaSmootherConfig', (_message.Message,), {
  'DESCRIPTOR' : _COSTHETASMOOTHERCONFIG,
  '__module__' : 'modules.planning.proto.math.cos_theta_smoother_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.CosThetaSmootherConfig)
  })
_sym_db.RegisterMessage(CosThetaSmootherConfig)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/perception/proto/perception_obstacle.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.common.proto import error_code_pb2 as modules_dot_common_dot_proto_dot_error__code__pb2
from modules.common.proto import geometry_pb2 as modules_dot_common_dot_proto_dot_geometry__pb2
from modules.common.proto import header_pb2 as modules_dot_common_dot_proto_dot_header__pb2
from modules.common.proto import pnc_point_pb2 as modules_dot_common_dot_proto_dot_pnc__point__pb2
from modules.map.proto import map_lane_pb2 as modules_dot_map_dot_proto_dot_map__lane__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/perception/proto/perception_obstacle.proto',
  package='apollo.perception',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n2modules/perception/proto/perception_obstacle.proto\x12\x11\x61pollo.perception\x1a%modules/common/proto/error_code.proto\x1a#modules/common/proto/geometry.proto\x1a!modules/common/proto/header.proto\x1a$modules/common/proto/pnc_point.proto\x1a modules/map/proto/map_lane.proto\"@\n\x06\x42\x42ox2D\x12\x0c\n\x04xmin\x18\x01 \x01(\x01\x12\x0c\n\x04ymin\x18\x02 \x01(\x01\x12\x0c\n\x04xmax\x18\x03 \x01(\x01\x12\x0c\n\x04ymax\x18\x04 \x01(\x01\"\xaf\x01\n\x0bLightStatus\x12\x15\n\rbrake_visible\x18\x01 \x01(\x01\x12\x17\n\x0f\x62rake_switch_on\x18\x02 \x01(\x01\x12\x19\n\x11left_turn_visible\x18\x03 \x01(\x01\x12\x1b\n\x13left_turn_switch_on\x18\x04 \x01(\x01\x12\x1a\n\x12right_turn_visible\x18\x05 \x01(\x01\x12\x1c\n\x14right_turn_switch_on\x18\x06 \x01(\x01\"\x83\x01\n\x0eV2XInformation\x12;\n\x08v2x_type\x18\x01 \x03(\x0e\x32).apollo.perception.V2XInformation.V2XType\"4\n\x07V2XType\x12\x08\n\x04NONE\x10\x00\x12\x0f\n\x0bZOMBIES_CAR\x10\x01\x12\x0e\n\nBLIND_ZONE\x10\x02\"\xfa\x02\n\x11SensorMeasurement\x12\x11\n\tsensor_id\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\x05\x12(\n\x08position\x18\x03 \x01(\x0b\x32\x16.apollo.common.Point3D\x12\r\n\x05theta\x18\x04 \x01(\x01\x12\x0e\n\x06length\x18\x05 \x01(\x01\x12\r\n\x05width\x18\x06 \x01(\x01\x12\x0e\n\x06height\x18\x07 \x01(\x01\x12(\n\x08velocity\x18\x08 \x01(\x0b\x32\x16.apollo.common.Point3D\x12\x38\n\x04type\x18\t \x01(\x0e\x32*.apollo.perception.PerceptionObstacle.Type\x12?\n\x08sub_type\x18\n \x01(\x0e\x32-.apollo.perception.PerceptionObstacle.SubType\x12\x11\n\ttimestamp\x18\x0b \x01(\x01\x12&\n\x03\x62ox\x18\x0c \x01(\x0b\x32\x19.apollo.perception.BBox2D\"[\n\nTrajectory\x12\x13\n\x0bprobability\x18\x01 \x01(\x01\x12\x38\n\x10trajectory_point\x18\x02 \x03(\x0b\x32\x1e.apollo.common.TrajectoryPoint\"A\n\x0c\x44\x65\x62ugMessage\x12\x31\n\ntrajectory\x18\x01 \x03(\x0b\x32\x1d.apollo.perception.Trajectory\"\xa9\x0c\n\x12PerceptionObstacle\x12\n\n\x02id\x18\x01 \x01(\x05\x12(\n\x08position\x18\x02 \x01(\x0b\x32\x16.apollo.common.Point3D\x12\r\n\x05theta\x18\x03 \x01(\x01\x12(\n\x08velocity\x18\x04 \x01(\x0b\x32\x16.apollo.common.Point3D\x12\x0e\n\x06length\x18\x05 \x01(\x01\x12\r\n\x05width\x18\x06 \x01(\x01\x12\x0e\n\x06height\x18\x07 \x01(\x01\x12-\n\rpolygon_point\x18\x08 \x03(\x0b\x32\x16.apollo.common.Point3D\x12\x15\n\rtracking_time\x18\t \x01(\x01\x12\x38\n\x04type\x18\n \x01(\x0e\x32*.apollo.perception.PerceptionObstacle.Type\x12\x11\n\ttimestamp\x18\x0b \x01(\x01\x12\x17\n\x0bpoint_cloud\x18\x0c \x03(\x01\x42\x02\x10\x01\x12\x16\n\nconfidence\x18\r \x01(\x01\x42\x02\x18\x01\x12Q\n\x0f\x63onfidence_type\x18\x0e \x01(\x0e\x32\x34.apollo.perception.PerceptionObstacle.ConfidenceTypeB\x02\x18\x01\x12)\n\x05\x64rops\x18\x0f \x03(\x0b\x32\x16.apollo.common.Point3DB\x02\x18\x01\x12,\n\x0c\x61\x63\x63\x65leration\x18\x10 \x01(\x0b\x32\x16.apollo.common.Point3D\x12,\n\x0c\x61nchor_point\x18\x11 \x01(\x0b\x32\x16.apollo.common.Point3D\x12)\n\x06\x62\x62ox2d\x18\x12 \x01(\x0b\x32\x19.apollo.perception.BBox2D\x12?\n\x08sub_type\x18\x13 \x01(\x0e\x32-.apollo.perception.PerceptionObstacle.SubType\x12:\n\x0cmeasurements\x18\x14 \x03(\x0b\x32$.apollo.perception.SensorMeasurement\x12 \n\x13height_above_ground\x18\x15 \x01(\x01:\x03nan\x12\x1f\n\x13position_covariance\x18\x16 \x03(\x01\x42\x02\x10\x01\x12\x1f\n\x13velocity_covariance\x18\x17 \x03(\x01\x42\x02\x10\x01\x12#\n\x17\x61\x63\x63\x65leration_covariance\x18\x18 \x03(\x01\x42\x02\x10\x01\x12\x34\n\x0clight_status\x18\x19 \x01(\x0b\x32\x1e.apollo.perception.LightStatus\x12,\n\x03msg\x18\x1a \x01(\x0b\x32\x1f.apollo.perception.DebugMessage\x12J\n\x06source\x18\x1b \x01(\x0e\x32,.apollo.perception.PerceptionObstacle.Source:\x0cHOST_VEHICLE\x12\x33\n\x08v2x_info\x18\x1c \x01(\x0b\x32!.apollo.perception.V2XInformation\"i\n\x04Type\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x13\n\x0fUNKNOWN_MOVABLE\x10\x01\x12\x15\n\x11UNKNOWN_UNMOVABLE\x10\x02\x12\x0e\n\nPEDESTRIAN\x10\x03\x12\x0b\n\x07\x42ICYCLE\x10\x04\x12\x0b\n\x07VEHICLE\x10\x05\"R\n\x0e\x43onfidenceType\x12\x16\n\x12\x43ONFIDENCE_UNKNOWN\x10\x00\x12\x12\n\x0e\x43ONFIDENCE_CNN\x10\x01\x12\x14\n\x10\x43ONFIDENCE_RADAR\x10\x02\"\xdc\x01\n\x07SubType\x12\x0e\n\nST_UNKNOWN\x10\x00\x12\x16\n\x12ST_UNKNOWN_MOVABLE\x10\x01\x12\x18\n\x14ST_UNKNOWN_UNMOVABLE\x10\x02\x12\n\n\x06ST_CAR\x10\x03\x12\n\n\x06ST_VAN\x10\x04\x12\x0c\n\x08ST_TRUCK\x10\x05\x12\n\n\x06ST_BUS\x10\x06\x12\x0e\n\nST_CYCLIST\x10\x07\x12\x13\n\x0fST_MOTORCYCLIST\x10\x08\x12\x11\n\rST_TRICYCLIST\x10\t\x12\x11\n\rST_PEDESTRIAN\x10\n\x12\x12\n\x0eST_TRAFFICCONE\x10\x0b\"#\n\x06Source\x12\x10\n\x0cHOST_VEHICLE\x10\x00\x12\x07\n\x03V2X\x10\x01\"\x95\x02\n\nLaneMarker\x12\x36\n\tlane_type\x18\x01 \x01(\x0e\x32#.apollo.hdmap.LaneBoundaryType.Type\x12\x0f\n\x07quality\x18\x02 \x01(\x01\x12\x14\n\x0cmodel_degree\x18\x03 \x01(\x05\x12\x13\n\x0b\x63\x30_position\x18\x04 \x01(\x01\x12\x18\n\x10\x63\x31_heading_angle\x18\x05 \x01(\x01\x12\x14\n\x0c\x63\x32_curvature\x18\x06 \x01(\x01\x12\x1f\n\x17\x63\x33_curvature_derivative\x18\x07 \x01(\x01\x12\x12\n\nview_range\x18\x08 \x01(\x01\x12\x17\n\x0flongitude_start\x18\t \x01(\x01\x12\x15\n\rlongitude_end\x18\n \x01(\x01\"\xfd\x01\n\x0bLaneMarkers\x12\x37\n\x10left_lane_marker\x18\x01 \x01(\x0b\x32\x1d.apollo.perception.LaneMarker\x12\x38\n\x11right_lane_marker\x18\x02 \x01(\x0b\x32\x1d.apollo.perception.LaneMarker\x12<\n\x15next_left_lane_marker\x18\x03 \x03(\x0b\x32\x1d.apollo.perception.LaneMarker\x12=\n\x16next_right_lane_marker\x18\x04 \x03(\x0b\x32\x1d.apollo.perception.LaneMarker\"6\n\x08\x43IPVInfo\x12\x0f\n\x07\x63ipv_id\x18\x01 \x01(\x05\x12\x19\n\x11potential_cipv_id\x18\x02 \x03(\x05\"\x97\x02\n\x13PerceptionObstacles\x12\x42\n\x13perception_obstacle\x18\x01 \x03(\x0b\x32%.apollo.perception.PerceptionObstacle\x12%\n\x06header\x18\x02 \x01(\x0b\x32\x15.apollo.common.Header\x12\x30\n\nerror_code\x18\x03 \x01(\x0e\x32\x18.apollo.common.ErrorCode:\x02OK\x12\x33\n\x0blane_marker\x18\x04 \x01(\x0b\x32\x1e.apollo.perception.LaneMarkers\x12.\n\tcipv_info\x18\x05 \x01(\x0b\x32\x1b.apollo.perception.CIPVInfo'
  ,
  dependencies=[modules_dot_common_dot_proto_dot_error__code__pb2.DESCRIPTOR,modules_dot_common_dot_proto_dot_geometry__pb2.DESCRIPTOR,modules_dot_common_dot_proto_dot_header__pb2.DESCRIPTOR,modules_dot_common_dot_proto_dot_pnc__point__pb2.DESCRIPTOR,modules_dot_map_dot_proto_dot_map__lane__pb2.DESCRIPTOR,])



_V2XINFORMATION_V2XTYPE = _descriptor.EnumDescriptor(
  name='V2XType',
  full_name='apollo.perception.V2XInformation.V2XType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ZOMBIES_CAR', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BLIND_ZONE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=580,
  serialized_end=632,
)
_sym_db.RegisterEnumDescriptor(_V2XINFORMATION_V2XTYPE)

_PERCEPTIONOBSTACLE_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='apollo.perception.PerceptionObstacle.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_MOVABLE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_UNMOVABLE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PEDESTRIAN', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BICYCLE', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VEHICLE', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2304,
  serialized_end=2409,
)
_sym_db.RegisterEnumDescriptor(_PERCEPTIONOBSTACLE_TYPE)

_PERCEPTIONOBSTACLE_CONFIDENCETYPE = _descriptor.EnumDescriptor(
  name='ConfidenceType',
  full_name='apollo.perception.PerceptionObstacle.ConfidenceType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CONFIDENCE_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CONFIDENCE_CNN', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CONFIDENCE_RADAR', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2411,
  serialized_end=2493,
)
_sym_db.RegisterEnumDescriptor(_PERCEPTIONOBSTACLE_CONFIDENCETYPE)

_PERCEPTIONOBSTACLE_SUBTYPE = _descriptor.EnumDescriptor(
  name='SubType',
  full_name='apollo.perception.PerceptionObstacle.SubType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ST_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ST_UNKNOWN_MOVABLE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ST_UNKNOWN_UNMOVABLE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ST_CAR', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ST_VAN', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ST_TRUCK', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ST_BUS', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ST_CYCLIST', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ST_MOTORCYCLIST', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ST_TRICYCLIST', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ST_PEDESTRIAN', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ST_TRAFFICCONE', index=11, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2496,
  serialized_end=2716,
)
_sym_db.RegisterEnumDescriptor(_PERCEPTIONOBSTACLE_SUBTYPE)

_PERCEPTIONOBSTACLE_SOURCE = _descriptor.EnumDescriptor(
  name='Source',
  full_name='apollo.perception.PerceptionObstacle.Source',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='HOST_VEHICLE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='V2X', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2718,
  serialized_end=2753,
)
_sym_db.RegisterEnumDescriptor(_PERCEPTIONOBSTACLE_SOURCE)


_BBOX2D = _descriptor.Descriptor(
  name='BBox2D',
  full_name='apollo.perception.BBox2D',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='xmin', full_name='apollo.perception.BBox2D.xmin', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ymin', full_name='apollo.perception.BBox2D.ymin', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='xmax', full_name='apollo.perception.BBox2D.xmax', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ymax', full_name='apollo.perception.BBox2D.ymax', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=256,
  serialized_end=320,
)


_LIGHTSTATUS = _descriptor.Descriptor(
  name='LightStatus',
  full_name='apollo.perception.LightStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='brake_visible', full_name='apollo.perception.LightStatus.brake_visible', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brake_switch_on', full_name='apollo.perception.LightStatus.brake_switch_on', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='left_turn_visible', full_name='apollo.perception.LightStatus.left_turn_visible', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='left_turn_switch_on', full_name='apollo.perception.LightStatus.left_turn_switch_on', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='right_turn_visible', full_name='apollo.perception.LightStatus.right_turn_visible', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='right_turn_switch_on', full_name='apollo.perception.LightStatus.right_turn_switch_on', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=323,
  serialized_end=498,
)


_V2XINFORMATION = _descriptor.Descriptor(
  name='V2XInformation',
  full_name='apollo.perception.V2XInformation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='v2x_type', full_name='apollo.perception.V2XInformation.v2x_type', index=0,
      number=1, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _V2XINFORMATION_V2XTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=501,
  serialized_end=632,
)


_SENSORMEASUREMENT = _descriptor.Descriptor(
  name='SensorMeasurement',
  full_name='apollo.perception.SensorMeasurement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sensor_id', full_name='apollo.perception.SensorMeasurement.sensor_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='apollo.perception.SensorMeasurement.id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='position', full_name='apollo.perception.SensorMeasurement.position', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='theta', full_name='apollo.perception.SensorMeasurement.theta', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='length', full_name='apollo.perception.SensorMeasurement.length', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='width', full_name='apollo.perception.SensorMeasurement.width', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='height', full_name='apollo.perception.SensorMeasurement.height', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='velocity', full_name='apollo.perception.SensorMeasurement.velocity', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='apollo.perception.SensorMeasurement.type', index=8,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sub_type', full_name='apollo.perception.SensorMeasurement.sub_type', index=9,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='apollo.perception.SensorMeasurement.timestamp', index=10,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='box', full_name='apollo.perception.SensorMeasurement.box', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=635,
  serialized_end=1013,
)


_TRAJECTORY = _descriptor.Descriptor(
  name='Trajectory',
  full_name='apollo.perception.Trajectory',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='probability', full_name='apollo.perception.Trajectory.probability', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trajectory_point', full_name='apollo.perception.Trajectory.trajectory_point', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1015,
  serialized_end=1106,
)


_DEBUGMESSAGE = _descriptor.Descriptor(
  name='DebugMessage',
  full_name='apollo.perception.DebugMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='trajectory', full_name='apollo.perception.DebugMessage.trajectory', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1108,
  serialized_end=1173,
)


_PERCEPTIONOBSTACLE = _descriptor.Descriptor(
  name='PerceptionObstacle',
  full_name='apollo.perception.PerceptionObstacle',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='apollo.perception.PerceptionObstacle.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='position', full_name='apollo.perception.PerceptionObstacle.position', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='theta', full_name='apollo.perception.PerceptionObstacle.theta', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='velocity', full_name='apollo.perception.PerceptionObstacle.velocity', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='length', full_name='apollo.perception.PerceptionObstacle.length', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='width', full_name='apollo.perception.PerceptionObstacle.width', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='height', full_name='apollo.perception.PerceptionObstacle.height', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='polygon_point', full_name='apollo.perception.PerceptionObstacle.polygon_point', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tracking_time', full_name='apollo.perception.PerceptionObstacle.tracking_time', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='apollo.perception.PerceptionObstacle.type', index=9,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='apollo.perception.PerceptionObstacle.timestamp', index=10,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='point_cloud', full_name='apollo.perception.PerceptionObstacle.point_cloud', index=11,
      number=12, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='confidence', full_name='apollo.perception.PerceptionObstacle.confidence', index=12,
      number=13, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='confidence_type', full_name='apollo.perception.PerceptionObstacle.confidence_type', index=13,
      number=14, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='drops', full_name='apollo.perception.PerceptionObstacle.drops', index=14,
      number=15, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acceleration', full_name='apollo.perception.PerceptionObstacle.acceleration', index=15,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='anchor_point', full_name='apollo.perception.PerceptionObstacle.anchor_point', index=16,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bbox2d', full_name='apollo.perception.PerceptionObstacle.bbox2d', index=17,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sub_type', full_name='apollo.perception.PerceptionObstacle.sub_type', index=18,
      number=19, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='measurements', full_name='apollo.perception.PerceptionObstacle.measurements', index=19,
      number=20, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='height_above_ground', full_name='apollo.perception.PerceptionObstacle.height_above_ground', index=20,
      number=21, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=(1e10000 * 0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='position_covariance', full_name='apollo.perception.PerceptionObstacle.position_covariance', index=21,
      number=22, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='velocity_covariance', full_name='apollo.perception.PerceptionObstacle.velocity_covariance', index=22,
      number=23, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acceleration_covariance', full_name='apollo.perception.PerceptionObstacle.acceleration_covariance', index=23,
      number=24, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='light_status', full_name='apollo.perception.PerceptionObstacle.light_status', index=24,
      number=25, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='msg', full_name='apollo.perception.PerceptionObstacle.msg', index=25,
      number=26, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source', full_name='apollo.perception.PerceptionObstacle.source', index=26,
      number=27, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='v2x_info', full_name='apollo.perception.PerceptionObstacle.v2x_info', index=27,
      number=28, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PERCEPTIONOBSTACLE_TYPE,
    _PERCEPTIONOBSTACLE_CONFIDENCETYPE,
    _PERCEPTIONOBSTACLE_SUBTYPE,
    _PERCEPTIONOBSTACLE_SOURCE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1176,
  serialized_end=2753,
)


_LANEMARKER = _descriptor.Descriptor(
  name='LaneMarker',
  full_name='apollo.perception.LaneMarker',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lane_type', full_name='apollo.perception.LaneMarker.lane_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quality', full_name='apollo.perception.LaneMarker.quality', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='model_degree', full_name='apollo.perception.LaneMarker.model_degree', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='c0_position', full_name='apollo.perception.LaneMarker.c0_position', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='c1_heading_angle', full_name='apollo.perception.LaneMarker.c1_heading_angle', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='c2_curvature', full_name='apollo.perception.LaneMarker.c2_curvature', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='c3_curvature_derivative', full_name='apollo.perception.LaneMarker.c3_curvature_derivative', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='view_range', full_name='apollo.perception.LaneMarker.view_range', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='longitude_start', full_name='apollo.perception.LaneMarker.longitude_start', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='longitude_end', full_name='apollo.perception.LaneMarker.longitude_end', index=9,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2756,
  serialized_end=3033,
)


_LANEMARKERS = _descriptor.Descriptor(
  name='LaneMarkers',
  full_name='apollo.perception.LaneMarkers',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='left_lane_marker', full_name='apollo.perception.LaneMarkers.left_lane_marker', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='right_lane_marker', full_name='apollo.perception.LaneMarkers.right_lane_marker', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_left_lane_marker', full_name='apollo.perception.LaneMarkers.next_left_lane_marker', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_right_lane_marker', full_name='apollo.perception.LaneMarkers.next_right_lane_marker', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3036,
  serialized_end=3289,
)


_CIPVINFO = _descriptor.Descriptor(
  name='CIPVInfo',
  full_name='apollo.perception.CIPVInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cipv_id', full_name='apollo.perception.CIPVInfo.cipv_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='potential_cipv_id', full_name='apollo.perception.CIPVInfo.potential_cipv_id', index=1,
      number=2, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3291,
  serialized_end=3345,
)


_PERCEPTIONOBSTACLES = _descriptor.Descriptor(
  name='PerceptionObstacles',
  full_name='apollo.perception.PerceptionObstacles',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='perception_obstacle', full_name='apollo.perception.PerceptionObstacles.perception_obstacle', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='header', full_name='apollo.perception.PerceptionObstacles.header', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error_code', full_name='apollo.perception.PerceptionObstacles.error_code', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_marker', full_name='apollo.perception.PerceptionObstacles.lane_marker', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cipv_info', full_name='apollo.perception.PerceptionObstacles.cipv_info', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3348,
  serialized_end=3627,
)

_V2XINFORMATION.fields_by_name['v2x_type'].enum_type = _V2XINFORMATION_V2XTYPE
_V2XINFORMATION_V2XTYPE.containing_type = _V2XINFORMATION
_SENSORMEASUREMENT.fields_by_name['position'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINT3D
_SENSORMEASUREMENT.fields_by_name['velocity'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINT3D
_SENSORMEASUREMENT.fields_by_name['type'].enum_type = _PERCEPTIONOBSTACLE_TYPE
_SENSORMEASUREMENT.fields_by_name['sub_type'].enum_type = _PERCEPTIONOBSTACLE_SUBTYPE
_SENSORMEASUREMENT.fields_by_name['box'].message_type = _BBOX2D
_TRAJECTORY.fields_by_name['trajectory_point'].message_type = modules_dot_common_dot_proto_dot_pnc__point__pb2._TRAJECTORYPOINT
_DEBUGMESSAGE.fields_by_name['trajectory'].message_type = _TRAJECTORY
_PERCEPTIONOBSTACLE.fields_by_name['position'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINT3D
_PERCEPTIONOBSTACLE.fields_by_name['velocity'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINT3D
_PERCEPTIONOBSTACLE.fields_by_name['polygon_point'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINT3D
_PERCEPTIONOBSTACLE.fields_by_name['type'].enum_type = _PERCEPTIONOBSTACLE_TYPE
_PERCEPTIONOBSTACLE.fields_by_name['confidence_type'].enum_type = _PERCEPTIONOBSTACLE_CONFIDENCETYPE
_PERCEPTIONOBSTACLE.fields_by_name['drops'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINT3D
_PERCEPTIONOBSTACLE.fields_by_name['acceleration'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINT3D
_PERCEPTIONOBSTACLE.fields_by_name['anchor_point'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINT3D
_PERCEPTIONOBSTACLE.fields_by_name['bbox2d'].message_type = _BBOX2D
_PERCEPTIONOBSTACLE.fields_by_name['sub_type'].enum_type = _PERCEPTIONOBSTACLE_SUBTYPE
_PERCEPTIONOBSTACLE.fields_by_name['measurements'].message_type = _SENSORMEASUREMENT
_PERCEPTIONOBSTACLE.fields_by_name['light_status'].message_type = _LIGHTSTATUS
_PERCEPTIONOBSTACLE.fields_by_name['msg'].message_type = _DEBUGMESSAGE
_PERCEPTIONOBSTACLE.fields_by_name['source'].enum_type = _PERCEPTIONOBSTACLE_SOURCE
_PERCEPTIONOBSTACLE.fields_by_name['v2x_info'].message_type = _V2XINFORMATION
_PERCEPTIONOBSTACLE_TYPE.containing_type = _PERCEPTIONOBSTACLE
_PERCEPTIONOBSTACLE_CONFIDENCETYPE.containing_type = _PERCEPTIONOBSTACLE
_PERCEPTIONOBSTACLE_SUBTYPE.containing_type = _PERCEPTIONOBSTACLE
_PERCEPTIONOBSTACLE_SOURCE.containing_type = _PERCEPTIONOBSTACLE
_LANEMARKER.fields_by_name['lane_type'].enum_type = modules_dot_map_dot_proto_dot_map__lane__pb2._LANEBOUNDARYTYPE_TYPE
_LANEMARKERS.fields_by_name['left_lane_marker'].message_type = _LANEMARKER
_LANEMARKERS.fields_by_name['right_lane_marker'].message_type = _LANEMARKER
_LANEMARKERS.fields_by_name['next_left_lane_marker'].message_type = _LANEMARKER
_LANEMARKERS.fields_by_name['next_right_lane_marker'].message_type = _LANEMARKER
_PERCEPTIONOBSTACLES.fields_by_name['perception_obstacle'].message_type = _PERCEPTIONOBSTACLE
_PERCEPTIONOBSTACLES.fields_by_name['header'].message_type = modules_dot_common_dot_proto_dot_header__pb2._HEADER
_PERCEPTIONOBSTACLES.fields_by_name['error_code'].enum_type = modules_dot_common_dot_proto_dot_error__code__pb2._ERRORCODE
_PERCEPTIONOBSTACLES.fields_by_name['lane_marker'].message_type = _LANEMARKERS
_PERCEPTIONOBSTACLES.fields_by_name['cipv_info'].message_type = _CIPVINFO
DESCRIPTOR.message_types_by_name['BBox2D'] = _BBOX2D
DESCRIPTOR.message_types_by_name['LightStatus'] = _LIGHTSTATUS
DESCRIPTOR.message_types_by_name['V2XInformation'] = _V2XINFORMATION
DESCRIPTOR.message_types_by_name['SensorMeasurement'] = _SENSORMEASUREMENT
DESCRIPTOR.message_types_by_name['Trajectory'] = _TRAJECTORY
DESCRIPTOR.message_types_by_name['DebugMessage'] = _DEBUGMESSAGE
DESCRIPTOR.message_types_by_name['PerceptionObstacle'] = _PERCEPTIONOBSTACLE
DESCRIPTOR.message_types_by_name['LaneMarker'] = _LANEMARKER
DESCRIPTOR.message_types_by_name['LaneMarkers'] = _LANEMARKERS
DESCRIPTOR.message_types_by_name['CIPVInfo'] = _CIPVINFO
DESCRIPTOR.message_types_by_name['PerceptionObstacles'] = _PERCEPTIONOBSTACLES
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

BBox2D = _reflection.GeneratedProtocolMessageType('BBox2D', (_message.Message,), {
  'DESCRIPTOR' : _BBOX2D,
  '__module__' : 'modules.perception.proto.perception_obstacle_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.BBox2D)
  })
_sym_db.RegisterMessage(BBox2D)

LightStatus = _reflection.GeneratedProtocolMessageType('LightStatus', (_message.Message,), {
  'DESCRIPTOR' : _LIGHTSTATUS,
  '__module__' : 'modules.perception.proto.perception_obstacle_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.LightStatus)
  })
_sym_db.RegisterMessage(LightStatus)

V2XInformation = _reflection.GeneratedProtocolMessageType('V2XInformation', (_message.Message,), {
  'DESCRIPTOR' : _V2XINFORMATION,
  '__module__' : 'modules.perception.proto.perception_obstacle_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.V2XInformation)
  })
_sym_db.RegisterMessage(V2XInformation)

SensorMeasurement = _reflection.GeneratedProtocolMessageType('SensorMeasurement', (_message.Message,), {
  'DESCRIPTOR' : _SENSORMEASUREMENT,
  '__module__' : 'modules.perception.proto.perception_obstacle_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.SensorMeasurement)
  })
_sym_db.RegisterMessage(SensorMeasurement)

Trajectory = _reflection.GeneratedProtocolMessageType('Trajectory', (_message.Message,), {
  'DESCRIPTOR' : _TRAJECTORY,
  '__module__' : 'modules.perception.proto.perception_obstacle_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.Trajectory)
  })
_sym_db.RegisterMessage(Trajectory)

DebugMessage = _reflection.GeneratedProtocolMessageType('DebugMessage', (_message.Message,), {
  'DESCRIPTOR' : _DEBUGMESSAGE,
  '__module__' : 'modules.perception.proto.perception_obstacle_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.DebugMessage)
  })
_sym_db.RegisterMessage(DebugMessage)

PerceptionObstacle = _reflection.GeneratedProtocolMessageType('PerceptionObstacle', (_message.Message,), {
  'DESCRIPTOR' : _PERCEPTIONOBSTACLE,
  '__module__' : 'modules.perception.proto.perception_obstacle_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.PerceptionObstacle)
  })
_sym_db.RegisterMessage(PerceptionObstacle)

LaneMarker = _reflection.GeneratedProtocolMessageType('LaneMarker', (_message.Message,), {
  'DESCRIPTOR' : _LANEMARKER,
  '__module__' : 'modules.perception.proto.perception_obstacle_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.LaneMarker)
  })
_sym_db.RegisterMessage(LaneMarker)

LaneMarkers = _reflection.GeneratedProtocolMessageType('LaneMarkers', (_message.Message,), {
  'DESCRIPTOR' : _LANEMARKERS,
  '__module__' : 'modules.perception.proto.perception_obstacle_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.LaneMarkers)
  })
_sym_db.RegisterMessage(LaneMarkers)

CIPVInfo = _reflection.GeneratedProtocolMessageType('CIPVInfo', (_message.Message,), {
  'DESCRIPTOR' : _CIPVINFO,
  '__module__' : 'modules.perception.proto.perception_obstacle_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.CIPVInfo)
  })
_sym_db.RegisterMessage(CIPVInfo)

PerceptionObstacles = _reflection.GeneratedProtocolMessageType('PerceptionObstacles', (_message.Message,), {
  'DESCRIPTOR' : _PERCEPTIONOBSTACLES,
  '__module__' : 'modules.perception.proto.perception_obstacle_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.PerceptionObstacles)
  })
_sym_db.RegisterMessage(PerceptionObstacles)


_PERCEPTIONOBSTACLE.fields_by_name['point_cloud']._options = None
_PERCEPTIONOBSTACLE.fields_by_name['confidence']._options = None
_PERCEPTIONOBSTACLE.fields_by_name['confidence_type']._options = None
_PERCEPTIONOBSTACLE.fields_by_name['drops']._options = None
_PERCEPTIONOBSTACLE.fields_by_name['position_covariance']._options = None
_PERCEPTIONOBSTACLE.fields_by_name['velocity_covariance']._options = None
_PERCEPTIONOBSTACLE.fields_by_name['acceleration_covariance']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/audio/proto/audio.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.audio.proto import audio_common_pb2 as modules_dot_audio_dot_proto_dot_audio__common__pb2
from modules.common.proto import geometry_pb2 as modules_dot_common_dot_proto_dot_geometry__pb2
from modules.common.proto import header_pb2 as modules_dot_common_dot_proto_dot_header__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/audio/proto/audio.proto',
  package='apollo.audio',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1fmodules/audio/proto/audio.proto\x12\x0c\x61pollo.audio\x1a&modules/audio/proto/audio_common.proto\x1a#modules/common/proto/geometry.proto\x1a!modules/common/proto/header.proto\"\xc6\x01\n\x0e\x41udioDetection\x12%\n\x06header\x18\x01 \x01(\x0b\x32\x15.apollo.common.Header\x12\x10\n\x08is_siren\x18\x02 \x01(\x08\x12:\n\rmoving_result\x18\x03 \x01(\x0e\x32\x1a.apollo.audio.MovingResult:\x07UNKNOWN\x12(\n\x08position\x18\x04 \x01(\x0b\x32\x16.apollo.common.Point3D\x12\x15\n\rsource_degree\x18\x05 \x01(\x01'
  ,
  dependencies=[modules_dot_audio_dot_proto_dot_audio__common__pb2.DESCRIPTOR,modules_dot_common_dot_proto_dot_geometry__pb2.DESCRIPTOR,modules_dot_common_dot_proto_dot_header__pb2.DESCRIPTOR,])




_AUDIODETECTION = _descriptor.Descriptor(
  name='AudioDetection',
  full_name='apollo.audio.AudioDetection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='apollo.audio.AudioDetection.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_siren', full_name='apollo.audio.AudioDetection.is_siren', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='moving_result', full_name='apollo.audio.AudioDetection.moving_result', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='position', full_name='apollo.audio.AudioDetection.position', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source_degree', full_name='apollo.audio.AudioDetection.source_degree', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=162,
  serialized_end=360,
)

_AUDIODETECTION.fields_by_name['header'].message_type = modules_dot_common_dot_proto_dot_header__pb2._HEADER
_AUDIODETECTION.fields_by_name['moving_result'].enum_type = modules_dot_audio_dot_proto_dot_audio__common__pb2._MOVINGRESULT
_AUDIODETECTION.fields_by_name['position'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINT3D
DESCRIPTOR.message_types_by_name['AudioDetection'] = _AUDIODETECTION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AudioDetection = _reflection.GeneratedProtocolMessageType('AudioDetection', (_message.Message,), {
  'DESCRIPTOR' : _AUDIODETECTION,
  '__module__' : 'modules.audio.proto.audio_pb2'
  # @@protoc_insertion_point(class_scope:apollo.audio.AudioDetection)
  })
_sym_db.RegisterMessage(AudioDetection)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/perception/proto/tracker_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/perception/proto/tracker_config.proto',
  package='',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n-modules/perception/proto/tracker_config.proto\"R\n\rMatcherConfig\x12\x1f\n\x12max_match_distance\x18\x01 \x01(\x01:\x03\x32.5\x12 \n\x14\x62ound_match_distance\x18\x02 \x01(\x01:\x02\x31\x30'
)




_MATCHERCONFIG = _descriptor.Descriptor(
  name='MatcherConfig',
  full_name='MatcherConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_match_distance', full_name='MatcherConfig.max_match_distance', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(2.5),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bound_match_distance', full_name='MatcherConfig.bound_match_distance', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(10),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=49,
  serialized_end=131,
)

DESCRIPTOR.message_types_by_name['MatcherConfig'] = _MATCHERCONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MatcherConfig = _reflection.GeneratedProtocolMessageType('MatcherConfig', (_message.Message,), {
  'DESCRIPTOR' : _MATCHERCONFIG,
  '__module__' : 'modules.perception.proto.tracker_config_pb2'
  # @@protoc_insertion_point(class_scope:MatcherConfig)
  })
_sym_db.RegisterMessage(MatcherConfig)


# @@protoc_insertion_point(module_scope)
